@@ -16,8 +16,5 @@
 # You should have received a copy of the GNU General Public License
 # along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 
-DATA_DIR = "@DATADIR@"
-LIB_DIR = "@LIBDIR@"
-VERSION = "0.1.90"
+VERSION = "0.2.1"
 PACKAGE = "gnome-dvb-daemon"
-PYTHONDIR = ""
