@@ -18,11 +18,11 @@
 
 from gettext import gettext as _
 import gobject
-import gtk
-import gtk.gdk
+from gi.repository import Gdk
+from gi.repository import Gtk
 import datetime
 
-class CalendarPopup(gtk.Window):
+class CalendarPopup(Gtk.Window):
 
     __gsignals__ = {
         "closed":  (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
@@ -30,48 +30,45 @@ class CalendarPopup(gtk.Window):
     }
 
     def __init__(self, dt=None):
-        gtk.Window.__init__(self, type=gtk.WINDOW_POPUP)
+        gobject.GObject.__init__(self, type=Gtk.WindowType.POPUP)
         self.set_border_width(5)
-        self.vbox = gtk.VBox(spacing=12)
+        self.vbox = Gtk.VBox(spacing=12)
         self.add(self.vbox)
-
+        
         self.connect("key-press-event", self._on_key_press_event)
         self.connect("button-press-event", self._on_button_press_event)
         
-        self.cal = gtk.Calendar()
+        self.cal = Gtk.Calendar()
         self.cal.connect("day-selected", self._emit_changed)
         self.cal.connect("day-selected-double-click", lambda w: self.popdown())
-        self.vbox.pack_start(self.cal)
+        self.vbox.pack_start(self.cal, True, True, 0)
+        
+        self.time_box = Gtk.HBox(spacing=12)
+        self.vbox.pack_start(self.time_box, False, True, 0)
 
-        self.time_box = gtk.HBox(spacing=12)
-        self.vbox.pack_start(self.time_box, False)
-
-        time_label = gtk.Label()
+        time_label = Gtk.Label()
         time_label.set_markup_with_mnemonic(_("_Time:"))
-        self.time_box.pack_start(time_label, False)
+        self.time_box.pack_start(time_label, False, True, 0)
 
-        ali = gtk.Alignment()
-        self.time_box.pack_start(ali)
+        spinners_box = Gtk.HBox(spacing=6)
+        self.time_box.pack_start(spinners_box, True, True, 0)
 
-        spinners_box = gtk.HBox(spacing=6)
-        ali.add(spinners_box)
-
-        self.hour = gtk.SpinButton()
+        self.hour = Gtk.SpinButton()
         self.hour.connect("changed", self._emit_changed)
         self.hour.set_range(0, 23)
         self.hour.set_increments(1, 3)
         self.hour.set_wrap(True)
         self.hour.set_width_chars(2)
-        spinners_box.pack_start(self.hour)
+        spinners_box.pack_start(self.hour, True, True, 0)
         time_label.set_mnemonic_widget(self.hour)
         
-        self.minute = gtk.SpinButton()
+        self.minute = Gtk.SpinButton()
         self.minute.connect("changed", self._emit_changed)
         self.minute.set_range(0, 59)
         self.minute.set_increments(1, 15)
         self.minute.set_wrap(True)
         self.minute.set_width_chars(2)
-        spinners_box.pack_start(self.minute)
+        spinners_box.pack_start(self.minute, True, True, 0)
 
         if dt == None:
             dt = datetime.datetime.now()
@@ -82,14 +79,14 @@ class CalendarPopup(gtk.Window):
         return self.cal
   
     def popup(self, widget):
-        if (self.flags() & gtk.MAPPED):
+        if (self.get_mapped()):
             return
-        if not (widget.flags() & gtk.MAPPED):
+        if not (widget.get_mapped()):
             return
-        if not (widget.flags() & gtk.REALIZED):
+        if not (widget.get_realized()):
             return
 
-        x, y = widget.window.get_position()
+        x, y = widget.get_window().get_position()
         rec = widget.get_allocation()
         x += rec.x
         y += rec.y + rec.height
@@ -99,7 +96,7 @@ class CalendarPopup(gtk.Window):
         self.show_all()
 
         # For grabbing to work we need the view realized
-        if not (self.flags() & gtk.REALIZED):
+        if not (self.get_realized()):
             self.realize ()
 
         self._add_grab()
@@ -122,76 +119,96 @@ class CalendarPopup(gtk.Window):
         return year, mon+1, day, hour, minute
 
     def _on_key_press_event(self, widget, event):
-        if event.keyval == gtk.keysyms.Escape:
+        if event.keyval == Gdk.KEY_Escape:
             self.popdown()
 
     def _on_button_press_event(self, widget, event):
-        x, y = self.window.get_position()
+        x, y = self.get_window().get_position()
+        alloc = widget.get_allocation()
         # Check if pointer is within the popup
-        if not (event.x_root >= x and event.x_root < x + widget.allocation.width \
-            and event.y_root >= y and event.y_root < y + widget.allocation.height):
+        if not (event.x_root >= x and event.x_root < x + alloc.width \
+            and event.y_root >= y and event.y_root < y + alloc.height):
             self.popdown()
 
     def _add_grab(self):
-        grab_val = gtk.gdk.pointer_grab(self.window, True,
-            gtk.gdk.BUTTON_PRESS_MASK | gtk.gdk.BUTTON_RELEASE_MASK,
-            None, None, gtk.get_current_event_time())
-        if grab_val == gtk.gdk.GRAB_SUCCESS:
-            if gtk.gdk.keyboard_grab(self.window, True) != gtk.gdk.GRAB_SUCCESS:
-                gtk.gdk.pointer_ungrab(gtk.get_current_event_time())
-            else:
-                self.grab_add()
+        window = self.get_window()
+
+        dev = Gtk.get_current_event_device()
+        grab_val = dev.grab(window, Gdk.GrabOwnership.WINDOW, True,
+            Gdk.EventMask.BUTTON_PRESS_MASK | Gdk.EventMask.BUTTON_RELEASE_MASK,
+            None, Gtk.get_current_event_time())
+        if grab_val == Gdk.GrabStatus.SUCCESS:
+            self.grab_add()
 
     def _remove_grab(self):
         self.grab_remove()
-        gtk.gdk.keyboard_ungrab(gtk.get_current_event_time())
-        gtk.gdk.pointer_ungrab(gtk.get_current_event_time())
+        dev = Gtk.get_current_event_device()
+        dev.ungrab(Gtk.get_current_event_time())
 
     def _emit_changed(self, *args):
         year, mon, day, hour, minute = self.get_date_and_time()
         self.emit("changed", year, mon, day, hour, minute)
 
 
-class DateTimeBox(gtk.Bin):
+class DateTimeBox(Gtk.Bin):
 
     __gsignals__ = {
         "changed": (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int, int, int, int, int]),
     }
 
     def __init__(self, dt=None):
-        gtk.Bin.__init__(self)
+        gobject.GObject.__init__(self)
 
-        self.hbox = gtk.HBox()
+        self.valid_color = None
+        self.invalid_color = None
 
-        self.entry = gtk.Entry()
+        self.hbox = Gtk.HBox()
+
+        self.entry = Gtk.Entry()
         self.entry.set_editable(False)
 
-        self.button = gtk.ToggleButton()
+        self.button = Gtk.ToggleButton()
         self.button.connect("toggled", self._on_button_toggled)
-        arrow = gtk.Arrow(gtk.ARROW_DOWN, gtk.SHADOW_NONE)
+        arrow = Gtk.Arrow.new(Gtk.ArrowType.DOWN, Gtk.ShadowType.NONE)
         self.button.add(arrow)
 
         if dt == None:
             dt = datetime.datetime.now()
 
-        self.popup_win = CalendarPopup(dt)
+        self.popup_win = CalendarPopup(dt)        
         self.popup_win.connect("changed", self._on_datetime_changed)
         self.popup_win.connect("closed", lambda w: self.button.set_active(False))
         
-        self.hbox.pack_start(self.entry)
-        self.hbox.pack_start(self.button, False)
+        self.hbox.pack_start(self.entry, True, True, 0)
+        self.hbox.pack_start(self.button, False, True, 0)
 
         self.add(self.hbox)
-        self.child.show_all()
+        self.get_child().show_all()
 
-    def do_size_request(self, req):
-        w, h = self.child.size_request()
-        req.width = w
-        req.height = h
+        self._set_colors()
+
+    def _set_colors(self):
+        style = self.entry.get_style_context()
+        self.valid_color = style.get_background_color(Gtk.StateFlags.NORMAL)
+        self.invalid_color = style.get_background_color(Gtk.StateFlags.INSENSITIVE)
 
     def do_size_allocate(self, alloc):
-        self.allocation = alloc
-        self.child.size_allocate(alloc)
+        self.set_allocation(alloc)
+        self.get_child().size_allocate(alloc)
+
+    def do_get_preferred_height(self):
+        val = self.get_child().get_preferred_height()
+        return val
+
+    def do_get_preferred_width(self):
+        val = self.get_child().get_preferred_width()
+        return val
+
+    def do_get_preferred_height_for_width(self, width):
+        return self.get_child().get_preferred_height_for_width(width)
+
+    def do_get_preferred_width_for_height(self, height):
+        return self.get_child().get_preferred_width_for_height(height)
 
     def do_mnemonic_activate(self, group_cycling):
         self.button.grab_focus()
@@ -199,10 +216,11 @@ class DateTimeBox(gtk.Bin):
 
     def mark_valid(self, val):
         if val:
-            color = self.style.text[gtk.STATE_NORMAL]
+            color = self.valid_color
         else:
-            color = self.style.text[gtk.STATE_INSENSITIVE]
-        self.entry.modify_text(gtk.STATE_NORMAL, color)
+            color = self.invalid_color
+
+        self.entry.override_background_color(Gtk.StateFlags.NORMAL, color)
 
     def get_date_and_time(self):
         return self.popup_win.get_date_and_time()
