@@ -81,7 +81,7 @@ class RunningNextView(Gtk.TreeView):
             data, success = result
             if not success:
                 return
-            event_id, next, name, duration, desc = data
+            event_id, next_id, name, duration, desc = data
             
             ext_desc, success = schedule.get_extended_description(event_id)
             if success:
@@ -120,9 +120,10 @@ class RunningNextView(Gtk.TreeView):
                     devgroup = model.get_device_group()
                     sid = model[aiter][RunningNextStore.COL_SID]
                     schedule = devgroup.get_schedule(sid)
-                    schedule.get_informations(event_id,
-                        result_handler=show_details,
-                        error_handler=global_error_handler)
+                    if schedule != None:
+                        schedule.get_informations(event_id,
+                            result_handler=show_details,
+                            error_handler=global_error_handler)
 
     def _on_record_clicked(self, button, data):
         def on_reply(proxy, data, user_data):
